Roadmap
=======

* v0.5
  * Refactor testing to be more intelligible.  Replace case keys with id factories.
* Future
  * SQLAlchemy/Spark as plugins
  * Streaming - I would like to be able to support streaming data subjects (like Kafka).
  * Auto-documentation - The testing framework should be able to support building
    documentation by collecting test scenario and case definitions.  Documents could be built
    to look something like Gherkin.
